==> kotlin-popper-2.11.5-pre.357.jar: kotlin-popper.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin', 'kotlin-js'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'), require('kotlin-js'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'kotlin-popper'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'kotlin-popper'.");
    }
    if (typeof this['kotlin-js'] === 'undefined') {
      throw new Error("Error loading module 'kotlin-popper'. Its dependency 'kotlin-js' was not found. Please, check whether 'kotlin-js' is loaded prior to 'kotlin-popper'.");
    }
    root['kotlin-popper'] = factory(typeof this['kotlin-popper'] === 'undefined' ? {} : this['kotlin-popper'], kotlin, this['kotlin-js']);
  }
}(this, function (_, Kotlin, $module$kotlin_js) {
  'use strict';
  var $$importsForInline$$ = _.$$importsForInline$$ || (_.$$importsForInline$$ = {});
  var defineInlineFunction = Kotlin.defineInlineFunction;
  var modifier = defineInlineFunction('kotlin-popper.popper.core.modifier_vp2qf3$', function ($receiver, block) {
    var $receiver_0 = {};
    $receiver_0.name = $receiver;
    block($receiver_0);
    return $receiver_0;
  });
  var ReferenceElement = defineInlineFunction('kotlin-popper.popper.core.ReferenceElement_ejp6n4$', function (source) {
    return source;
  });
  var ReferenceElement_0 = defineInlineFunction('kotlin-popper.popper.core.ReferenceElement_i2m5mn$', function (source) {
    return source;
  });
  var PaddingFunction = defineInlineFunction('kotlin-popper.popper.core.modifiers.PaddingFunction_57ciie$', function (fn) {
    return fn;
  });
  var Padding = defineInlineFunction('kotlin-popper.popper.core.modifiers.Padding_14dthe$', function (padding) {
    return padding;
  });
  var Padding_0 = defineInlineFunction('kotlin-popper.popper.core.modifiers.Padding_fj0o5p$', function (block) {
    var $receiver = {};
    block($receiver);
    return $receiver;
  });
  var Offset = defineInlineFunction('kotlin-popper.popper.core.modifiers.Offset_jma9l8$', function (x, y) {
    return [x, y];
  });
  var OffsetFunction = defineInlineFunction('kotlin-popper.popper.core.modifiers.OffsetFunction_p7kjbl$', function (fn) {
    return fn;
  });
  var TetherOffset = defineInlineFunction('kotlin-popper.popper.core.modifiers.TetherOffset_14dthe$', function (x) {
    return x;
  });
  var TetherOffsetFunction = defineInlineFunction('kotlin-popper.popper.core.modifiers.TetherOffsetFunction_7x8j74$', function (fn) {
    return fn;
  });
  $$importsForInline$$['kotlin-popper'] = _;
  $$importsForInline$$['kotlin-js'] = $module$kotlin_js;
  var package$popper = _.popper || (_.popper = {});
  var package$core = package$popper.core || (package$popper.core = {});
  package$core.modifier_vp2qf3$ = modifier;
  package$core.ReferenceElement_ejp6n4$ = ReferenceElement;
  package$core.ReferenceElement_i2m5mn$ = ReferenceElement_0;
  var package$modifiers = package$core.modifiers || (package$core.modifiers = {});
  package$modifiers.PaddingFunction_57ciie$ = PaddingFunction;
  package$modifiers.Padding_14dthe$ = Padding;
  package$modifiers.Padding_fj0o5p$ = Padding_0;
  package$modifiers.Offset_jma9l8$ = Offset;
  package$modifiers.OffsetFunction_p7kjbl$ = OffsetFunction;
  package$modifiers.TetherOffset_14dthe$ = TetherOffset;
  package$modifiers.TetherOffsetFunction_7x8j74$ = TetherOffsetFunction;
  Kotlin.defineModule('kotlin-popper', _);
  return _;
}));

==> kotlin-popper-2.11.6-pre.462.jar: kotlin-popper.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin', 'kotlin-js'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'), require('kotlin-js'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'kotlin-popper'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'kotlin-popper'.");
    }
    if (typeof this['kotlin-js'] === 'undefined') {
      throw new Error("Error loading module 'kotlin-popper'. Its dependency 'kotlin-js' was not found. Please, check whether 'kotlin-js' is loaded prior to 'kotlin-popper'.");
    }
    root['kotlin-popper'] = factory(typeof this['kotlin-popper'] === 'undefined' ? {} : this['kotlin-popper'], kotlin, this['kotlin-js']);
  }
}(this, function (_, Kotlin, $module$kotlin_js) {
  'use strict';
  var $$importsForInline$$ = _.$$importsForInline$$ || (_.$$importsForInline$$ = {});
  var defineInlineFunction = Kotlin.defineInlineFunction;
  var modifier = defineInlineFunction('kotlin-popper.popper.core.modifier_vp2qf3$', function ($receiver, block) {
    var $receiver_0 = {};
    $receiver_0.name = $receiver;
    block($receiver_0);
    return $receiver_0;
  });
  var ReferenceElement = defineInlineFunction('kotlin-popper.popper.core.ReferenceElement_gi3x1r$', function (source) {
    return source;
  });
  var ReferenceElement_0 = defineInlineFunction('kotlin-popper.popper.core.ReferenceElement_i2m5mn$', function (source) {
    return source;
  });
  var PaddingFunction = defineInlineFunction('kotlin-popper.popper.core.modifiers.PaddingFunction_57ciie$', function (fn) {
    return fn;
  });
  var Padding = defineInlineFunction('kotlin-popper.popper.core.modifiers.Padding_14dthe$', function (padding) {
    return padding;
  });
  var Padding_0 = defineInlineFunction('kotlin-popper.popper.core.modifiers.Padding_fj0o5p$', function (block) {
    var $receiver = {};
    block($receiver);
    return $receiver;
  });
  var Offset = defineInlineFunction('kotlin-popper.popper.core.modifiers.Offset_jma9l8$', function (x, y) {
    return [x, y];
  });
  var OffsetFunction = defineInlineFunction('kotlin-popper.popper.core.modifiers.OffsetFunction_2s7sf7$', function (fn) {
    return fn;
  });
  var TetherOffset = defineInlineFunction('kotlin-popper.popper.core.modifiers.TetherOffset_14dthe$', function (x) {
    return x;
  });
  var TetherOffsetFunction = defineInlineFunction('kotlin-popper.popper.core.modifiers.TetherOffsetFunction_7x8j74$', function (fn) {
    return fn;
  });
  $$importsForInline$$['kotlin-popper'] = _;
  $$importsForInline$$['kotlin-js'] = $module$kotlin_js;
  var package$popper = _.popper || (_.popper = {});
  var package$core = package$popper.core || (package$popper.core = {});
  package$core.modifier_vp2qf3$ = modifier;
  package$core.ReferenceElement_gi3x1r$ = ReferenceElement;
  package$core.ReferenceElement_i2m5mn$ = ReferenceElement_0;
  var package$modifiers = package$core.modifiers || (package$core.modifiers = {});
  package$modifiers.PaddingFunction_57ciie$ = PaddingFunction;
  package$modifiers.Padding_14dthe$ = Padding;
  package$modifiers.Padding_fj0o5p$ = Padding_0;
  package$modifiers.Offset_jma9l8$ = Offset;
  package$modifiers.OffsetFunction_2s7sf7$ = OffsetFunction;
  package$modifiers.TetherOffset_14dthe$ = TetherOffset;
  package$modifiers.TetherOffsetFunction_7x8j74$ = TetherOffsetFunction;
  Kotlin.defineModule('kotlin-popper', _);
  return _;
}));
